@@ -1,4 +1,4 @@
-use base64::{encode_config, CharacterSet, Config};
+use base64::{engine::general_purpose::STANDARD_NO_PAD, Engine};
 
 #[derive(Debug)]
 pub struct Authentication {
@@ -8,9 +8,7 @@ pub struct Authentication {
 
 impl Authentication {
     pub fn base64_encoded(&self) -> String {
-        let config = Config::new(CharacterSet::Standard, false);
         let auth = format!("{}:{}", &self.username, &self.password);
-
-        format!("Basic {}=", encode_config(auth, config))
+        format!("Basic {}=", STANDARD_NO_PAD.encode(auth))
     }
 }
